# authorized_rails_scaffolds

Replaces Rails and RSpec's default generators with templates taking full advantage of Authentication, Authorization and Test Coverage.

Originally Developed for Devise, CanCan and RSpec, the generated templates can be changed to handle most authorization, authentication and testing solutions with minimal effort.

## Features

### No Namespacing of Models

- Removes the Controller's namespace from the generated Controllers, allowing `rails g scaffold_controller admin/example` to handle `Example` models by default.

### Better RSpec Coverage for generated Controllers and Views

- Standard behaviour is tested to ensure that all code functions as expected
- Authenticated is tested, to ensure that users are refused access until they have signed in.
- Authorization is tested, to ensure that users are only able to view content if they have access to it.

## Installation

Add this line to your application's Gemfile:

    gem 'authorized_rails_scaffolds', :group => :development

Create a initializer at `config/initializers/authorized_rails_scaffolds.rb` containing:

    if Rails.env.development? 
    
      AuthorizedRailsScaffolds.configure do |config|
        # i.e. ['Category', 'User'] for Awesome/FooBar => awesome_category_user_foo_bars_path
        config.parent_models = []

        # toggles if shallow routes should be used
        config.shallow_routes = false
      end
      
    end

And then execute:

    $ bundle
    $ rails g authorized_rails_scaffolds:install_templates
    $ rails g authorized_rails_scaffolds:install_macros

## Usage

`authorized_rails_scaffolds` provides a series of rails generators that replace the default scaffold templates generated by Rails.

The generated Controllers require CanCan to be installed on your system, however it is possible change this behavour by uncommenting out the first line of each generated action manually.

The generated Controller only handles Authorization and assumes Authentication is managed in the Application Controller or is added manually.

This gem doesn't override the default scaffold.css generated by `rails g scaffold`, however it works best with `rails g scaffold_controller`.

For example:

    rails g model FooBar name:string age:integer date_of_birth:date lunch_time:time programmer:boolean joined_at:datetime
    rails g scaffold_controller Awesome/FooBar name:string age:integer date_of_birth:date lunch_time:time programmer:boolean joined_at:datetime

## Contributing

1. Fork it
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create new Pull Request

## License

Copyright (c) 2013 Ben Morrall

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
